@@ -2156,4 +2156,22 @@ export default function waitUntil(callback, options = {}) {
             |p| p.parse_expr(),
         );
     }
+
+    #[test]
+    #[should_panic(expected = "Only named exports may use 'export type'.")]
+    fn error_for_type_only_star_exports_with_name() {
+        let src = "export type * as bar from 'mod'";
+        test_parser(src, Syntax::Typescript(Default::default()), |p| {
+            p.parse_module()
+        });
+    }
+
+    #[test]
+    #[should_panic(expected = "Only named exports may use 'export type'.")]
+    fn error_for_type_only_star_exports_without_name() {
+        let src = "export type * from 'mod'";
+        test_parser(src, Syntax::Typescript(Default::default()), |p| {
+            p.parse_module()
+        });
+    }
 }
